def mulai():
    print("==========================================")
    print("============= Kalkulator BMI =============")
    print("==========================================")
    while True:
        pilihan = input("Mulai Program (y/n) ? : ")
        pilihan = pilihan.lower()
        print("==========================================")
        if pilihan == "y":
            tinggi_badan = int(input("Masukan Tinggi Badan anda (Cm) : "))
            berat_badan = int(input("Masukan Berat Badan anda (Kg) : "))
            print("==========================================")
            tinggi_badan = tinggi_badan / 100
            hitung_bmi = berat_badan / tinggi_badan ** 2
            hitung_bmi = round(hitung_bmi, 1)

            if hitung_bmi < 18.5:
                print(f"Index BMI : {hitung_bmi}, Kurang Berat Badan")
            elif hitung_bmi >= 18.5 and hitung_bmi <= 22.9:
                print(f"Index BMI : {hitung_bmi}, Normal")
            elif hitung_bmi >= 23 and hitung_bmi <= 24.9:
                print(f"Index BMI : {hitung_bmi}, Kelebihan Berat Badan")
            elif hitung_bmi >= 25 and hitung_bmi <= 29.9:
                print(f"Index BMI : {hitung_bmi}, Obesitas Tingkat 1")
            else:
                print(f"Index BMI : {hitung_bmi}, Obesitas Tingkat 2")
            print("==========================================")
        elif pilihan == 'n':
            print("Program Berhenti")
            break
        else:
            print("Jawaban Invalid")


if __name__ == 'main':
    mulai()



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="kalkulator_bmi",
    version="0.1",
    author="Muhammad Iqbal",
    author_email="miqbal020@hotmail.com",
    description="Paket ini berisi kalkulator yang berfungsi untuk menghitung BMI atau IMT",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Miqbal20/kalkulator_bmi",
    project_urls={
        "Website": "https://replit.com/@miqbal20",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Development Status :: 4 - Beta"
    ],
    # package_dir={"": "src"},
    # packages=setuptools.find_packages(where="src"),
    packages=setuptools.find_packages(),
    python_requires=">=3.7",
)